@@ -111,7 +111,6 @@ int llseek ( unsigned int, unsigned long long, unsigned int);
 #include <lvm.h>
 
 #include "lvm_log.h"
-#include "lvm_config.h"
 
 /* FIXME: get rid of these from lib code */
 #define FALSE	0
@@ -191,6 +190,7 @@ typedef enum {
   LVM_DEVICE_TYPE_COMPAQ_CISS,	/* Compaq CCISS array			*/
   LVM_DEVICE_TYPE_UBD,		/* User-mode virtual block device	*/
   LVM_DEVICE_TYPE_ATARAID,	/* ATA Raid				*/
+  LVM_DEVICE_TYPE_I2O,		/* i2o block device */
 } lvm_device_type_t;
 
 /* for lvm_show_size () */
