@@ -1,11 +1,12 @@
 /*
  * tools/lib/lv_change_vgname.c
  *
- * Copyright (C) 1997 - 1998  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * May 1997
  * June 1998
  * January,November 2000
+ * February 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -32,6 +33,8 @@
  *    12/06/1998 - added debug return output
  *    31/01/2000 - use debug_enter()/debug_leave()
  *    07/11/2000 - check if lv_name includes path
+ *    07/02/2002 - avoid buffer overflows
+ *
  */
 
 #include <liblvm.h>
@@ -39,26 +42,24 @@
 char *lv_change_vgname ( char *vg_name, char *lv_name) {
    char *lv_name_ptr = NULL;
    char *ret = NULL;
-   static char lv_name_buf[NAME_LEN] = { 0, };
+   static char lv_name_buf[NAME_LEN];
 
-#ifdef DEBUG
    debug_enter ( "lv_change_vgname -- CALLED\n");
-#endif
 
    if ( vg_name == NULL || vg_check_name ( vg_name) < 0 ||
         lv_name == NULL || lv_check_name ( lv_name) < 0) {
       ret = NULL;
    } else {
       /* check if lv_name includes a path */
+      memset ( lv_name_buf, 0, sizeof ( lv_name_buf));
       if ( ( lv_name_ptr = strrchr ( lv_name, '/')) != NULL) {
          lv_name_ptr++;
-         sprintf ( lv_name_buf, LVM_DIR_PREFIX "%s/%s%c", vg_name, lv_name_ptr, 0);
-      } else strncpy ( lv_name_buf, lv_name, NAME_LEN-1);
+         snprintf ( lv_name_buf, sizeof ( lv_name_buf) - 1,
+                    LVM_DIR_PREFIX "%s/%s%c", vg_name, lv_name_ptr, 0);
+      } else strncpy ( lv_name_buf, lv_name, sizeof ( lv_name_buf) - 1);
       ret = lv_name_buf;
    }
 
-#ifdef DEBUG
    debug_leave ( "lv_change_vgname -- LEAVING with ret: %s\n", ret);
-#endif
    return ret;
 }
