@@ -67,7 +67,9 @@ int lv_create_remove ( vg_t *vg, lv_t *lv, char *lv_name, int cr) {
       goto lv_create_remove_end;
    }
 
-   sprintf ( group_file, LVM_DIR_PREFIX "%s/group", vg->vg_name);
+   memset ( group_file, 0, sizeof ( group_file));
+   snprintf ( group_file, sizeof ( group_file) - 1,
+              LVM_DIR_PREFIX "%s/group", vg->vg_name);
    strcpy ( req.lv_name, lv_name);
    req.lv = lv;
    if ( ( group = open ( group_file, O_RDWR)) == -1) {
