@@ -1,7 +1,7 @@
 /*
  * tools/lib/lv_extend_reduce.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * April 1997
  * January 1999
@@ -36,15 +36,15 @@
 #include <liblvm.h>
 
 /* internal function */
-inline int lv_extend_reduce ( vg_t *, lv_t *, char *, int);
+int lv_extend_reduce ( vg_t *, lv_t *, char *, int);
 
 
-inline int lv_extend ( vg_t *vg, lv_t *lv, char *lv_name) {
+int lv_extend ( vg_t *vg, lv_t *lv, char *lv_name) {
    return lv_extend_reduce ( vg, lv, lv_name, LV_EXTEND);
 }
 
 
-inline int lv_reduce ( vg_t *vg, lv_t *lv, char *lv_name) {
+int lv_reduce ( vg_t *vg, lv_t *lv, char *lv_name) {
    return lv_extend_reduce ( vg, lv, lv_name, LV_REDUCE);
 }
 
@@ -55,9 +55,7 @@ int lv_extend_reduce ( vg_t *vg, lv_t *lv, char *lv_name, int er) {
    char group_file[NAME_LEN] = { 0, };
    lv_req_t req;
 
-#ifdef DEBUG
    debug_enter ( "lv_extend_reduce -- CALLED\n");
-#endif
 
    if ( vg == NULL ||
         ( ret = vg_check_consistency ( vg)) < 0 ||
@@ -69,30 +67,27 @@ int lv_extend_reduce ( vg_t *vg, lv_t *lv, char *lv_name, int er) {
       goto lv_extend_reduce_end;
    }
 
-   sprintf ( group_file, LVM_DIR_PREFIX "%s/group%c", vg->vg_name, 0);
+   memset ( group_file, 0, sizeof ( group_file));
+   snprintf ( group_file, sizeof ( group_file) - 1,
+              LVM_DIR_PREFIX "%s/group", vg->vg_name);
    strcpy ( req.lv_name, lv_name);
    req.lv = lv;
    if ( ( group = open ( group_file, O_RDWR)) == -1) {
       ret = -LVM_ELV_EXTEND_REDUCE_OPEN;
       goto lv_extend_reduce_end;
    }
-#ifdef DEBUG
    debug ( "lv_extend_reduce -- BEFORE ioctl\n");
-#endif
    if ( ( ret = ioctl ( group, er, &req)) == -1) ret = -errno;
    close ( group);
    if ( ret < 0) goto lv_extend_reduce_end;
-#ifdef DEBUG
    debug ( "lv_extend_reduce -- BEFORE pv_change_all_pv_for_lv_of_vg\n");
-#endif
    if ( er == LV_EXTEND)
       ret = pv_change_all_pv_for_lv_of_vg ( vg->vg_name, lv_name, vg);
    else
       ret = pv_change_all_pv_of_vg ( vg->vg_name, vg);
 
 lv_extend_reduce_end:
-#ifdef DEBUG
+
    debug_leave ( "lv_extend_reduce -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
