@@ -42,11 +42,9 @@ int lv_write ( char *pv_name, vg_t *vg, lv_t *lv, int l) {
    int ret  = 0;
    lv_disk_t *lv_disk = NULL;
 
-#ifdef DEBUG
    debug_enter ( "lv_write -- CALLED with pv_name: %s  vg->vg_name: %s  "
                  "lv->lv_name: %s  index: %d\n",
                  pv_name, vg->vg_name, lv->lv_name, l);
-#endif
 
    if ( pv_name == NULL ||
         pv_check_name ( pv_name) < 0 ||
@@ -76,8 +74,6 @@ int lv_write ( char *pv_name, vg_t *vg, lv_t *lv, int l) {
       free ( lv_disk);
    }
 
-#ifdef DEBUG
    debug_leave ( "lv_write -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
