@@ -60,6 +60,9 @@ int lvm_check_dev ( struct stat *stat_b, int check_mode) {
 #endif
 #ifdef ATARAID_MAJOR
       ATARAID_MAJOR,
+#endif
+#ifdef I2O_MAJOR
+      I2O_MAJOR,
 #endif
       -1
    };
