@@ -40,12 +40,12 @@
 
 #include <liblvm.h>
 
-#define TERABYTE	( 1024 * 1024 * 1024)
+#define TERABYTE	( 1024 * 1024 *1024)
 
 char *lvm_show_size ( unsigned long long size, size_len_t sl) {
    int s;
    int sz;
-   ulong byte = TERABYTE;
+   unsigned long long byte = TERABYTE;
    char *size_buf = NULL;
    char *ret = NULL;
    static char size_char[] = "TGMK";
@@ -63,16 +63,19 @@ char *lvm_show_size ( unsigned long long size, size_len_t sl) {
       memset ( size_buf, 0, NAME_LEN);
       ret = size_buf;
       if (size == 0LL) {
-	  sz += sprintf(size_buf, "0");
-      }
-      for (s = 0; size_char[s]; s++) {
-         if (size >= byte) {
-            sz = sprintf(size_buf, "%.2f", (float) size / byte);
+	  sz += sprintf ( size_buf, "0");
+      } else for ( s = 0; size_char[s]; s++) {
+         if ( size >= byte) {
+            sz = snprintf ( size_buf, NAME_LEN - 1, "%.2f",
+                                      (double) size / byte);
+            if ( strcmp ( &size_buf[sz-3], ".00") == 0) sz -= 3;
             if (size_buf[sz-1] == '.') sz--;
             if (sl == LONG)
-               sz += sprintf(&size_buf[sz], " %sbyte", size_string[s]);
+               sz += snprintf ( &size_buf[sz], NAME_LEN - sz - 1,
+                                               " %sbyte", size_string[s]);
             else
-               sz += sprintf(&size_buf[sz], " %cB", size_char[s]);
+               sz += snprintf ( &size_buf[sz], NAME_LEN - sz - 1,
+                                               " %cB", size_char[s]);
             break;
          }
          byte /= 1024;
