@@ -1,9 +1,10 @@
 /*
  * tools/lib/lvm_tab_check_free_lv_numbers.c
  *
- * Copyright (C) 2001  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 2001-2003  Heinz Mauelshagen, Sistina Software
  *
  * October 2001
+ * Sepetember 2003
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -28,6 +29,7 @@
  *
  *    23/10/2001 - first drop
  *    30/10/2001 - loop to lv_max ignoring null entries
+ *    02/09/2003 - free array of free block device numbers
  *
  */
 
@@ -39,6 +41,7 @@
 int lvm_tab_check_free_lv_number ( lv_t *lv) {
    int b;
    int blk_dev_free_count;
+   int ret = FALSE;
    kdev_t *blk_dev_free = NULL;
    kdev_t lv_dev = 0;
 
@@ -47,10 +50,14 @@ int lvm_tab_check_free_lv_number ( lv_t *lv) {
 
    lv_dev = lv->lv_dev;
    for ( b = 0; b < blk_dev_free_count; b++) {
-      if ( blk_dev_free[b] == lv_dev) return TRUE;
+      if ( blk_dev_free[b] == lv_dev) {
+         ret = TRUE;
+         break;
+      }
    }
 
-   return FALSE;
+   free ( blk_dev_free);
+   return ret;
 }
 
 int lvm_tab_check_free_lv_numbers ( vg_t *vg) {
