@@ -1,9 +1,11 @@
 /*
  * tools/lib/lvm_tab_get_free_blk_dev.c
  *
- * Copyright (C) 1999  Heinz Mauelshagen, Germany
+ * Copyright (C) 1999-2003  Heinz Mauelshagen, Sistina Software
  *
- * February-March 1999
+ * February-March,September 1999
+ * January 2000
+ * Sepetember 2003
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -23,6 +25,16 @@
  *
  */
 
+/*
+ * Changelog
+ *
+ *    29/10/1999 - fixed possible free() bug
+ *    31/01/2000 - use debug_enter()/debug_leave()
+ *    02/09/2003 - avoid to free array of block devices; up to the caller
+ *
+ */
+
+
 
 #include <liblvm.h>
 
@@ -47,14 +59,16 @@ int lvm_tab_get_free_blk_dev ( kdev_t **lv_blk_dev_free) {
    int lv_blk_dev_free_count = 0;
    int i = 0;
    int ret = 0;
-   kdev_t lv_dev = LVM_BLOCK_MAJOR << MINORBITS;
+   kdev_t lv_dev = MKDEV(LVM_BLK_MAJOR, 0);
    char **vg_name_ptr = NULL;
    vg_t *vg = NULL;
    kdev_t *lv_dev_this = NULL;
    kdev_t *lv_dev_this_sav = NULL;
-   static kdev_t *lv_blk_dev_free_this = NULL;
+   kdev_t *lv_blk_dev_free_this = NULL;
    kdev_t *lv_blk_dev_free_this_sav = NULL;
 
+   debug_enter ( "lvm_tab_get_free_blk_dev -- CALLED\n");
+
    if ( ( vg_name_ptr = lvm_tab_vg_check_exist_all_vg ()) != NULL) {
       while ( *vg_name_ptr != NULL) {
          if ( ( ret = lvm_tab_vg_check_exist ( *vg_name_ptr, &vg)) < 0) {
@@ -66,6 +80,7 @@ int lvm_tab_get_free_blk_dev ( kdev_t **lv_blk_dev_free) {
             for ( l = 0; l < vg->lv_max; l++) {
                if ( vg->lv[l] == NULL) continue;
                lv_dev_count++;
+
                lv_dev_this_sav = lv_dev_this;
                if ( ( lv_dev_this = realloc ( lv_dev_this,
                                               lv_dev_count *
@@ -73,7 +88,8 @@ int lvm_tab_get_free_blk_dev ( kdev_t **lv_blk_dev_free) {
                   if ( lv_dev_this_sav != NULL) free ( lv_dev_this_sav);
                   ret = -LVM_ELVM_TAB_GET_FREE_BLK_DEV_REALLOC;
                   goto lvm_tab_get_free_blk_dev_end;
-               } lv_dev_this[lv_dev_count-1] = vg->lv[l]->lv_dev;
+               } else lv_dev_this_sav = NULL;
+               lv_dev_this[lv_dev_count-1] = vg->lv[l]->lv_dev;
             }
             vg_free ( vg, FALSE);
          }
@@ -82,17 +98,13 @@ int lvm_tab_get_free_blk_dev ( kdev_t **lv_blk_dev_free) {
 
       if ( lv_blk_dev_free == NULL) {
          GET_LV_DEV;
-         if ( lv_dev < ( LVM_BLOCK_MAJOR << MINORBITS) + MAX_LV) ret = lv_dev;
+         if ( lv_dev < MKDEV(LVM_BLK_MAJOR, MAX_LV)) ret = lv_dev;
          else ret = -LVM_ELVM_TAB_GET_FREE_BLK_DEV_NO_DEV;
       } else {
-         if ( lv_blk_dev_free_this != NULL) {
-            free ( lv_blk_dev_free_this);
-            lv_blk_dev_free_this = NULL;
-         }
          lv_blk_dev_free_count = 0;
-         while ( lv_dev < ( LVM_BLOCK_MAJOR << MINORBITS) + MAX_LV) {
+         while ( lv_dev < MKDEV(LVM_BLK_MAJOR, MAX_LV)) {
             GET_LV_DEV;
-            if ( lv_dev < ( LVM_BLOCK_MAJOR << MINORBITS) + MAX_LV) {
+            if ( lv_dev < MKDEV(LVM_BLK_MAJOR, MAX_LV)) {
                lv_blk_dev_free_this_sav = lv_blk_dev_free_this;
                lv_blk_dev_free_count++;
                if ( ( lv_blk_dev_free_this =
@@ -129,5 +141,6 @@ lvm_tab_get_free_blk_dev_end:
    if ( lv_blk_dev_free_this != NULL && lv_blk_dev_free != NULL)
       *lv_blk_dev_free = lv_blk_dev_free_this;
 
+   debug_leave ( "lvm_tab_get_free_blk_dev -- LEAVING with ret: %d\n", ret);
    return ret;
 }
