@@ -81,13 +81,15 @@ int lvm_tab_vg_check_exist ( char *vg_name, vg_t **vg_ptr) {
    }
 
    if ( ret == TRUE) {
-      sprintf ( lvmtab_path, "%s/%s", LVMTAB_DIR, vg_name);
+      memset ( lvmtab_path, 0, sizeof ( lvmtab_path));
+      snprintf ( lvmtab_path, sizeof ( lvmtab_path) - 1,
+                              "%s/%s", LVMTAB_DIR, vg_name);
       if ( ( ret = vg_cfgrestore ( vg_name, lvmtab_path, 0, &vg)) == 0) {
          ret = TRUE;
          for ( p = 0; p < vg.pv_cur; p++) {
             if ( strcmp ( vg_name, vg.pv[p]->vg_name) == 0) {
                pv_count++;
-               if ( vg.pv[p]->version != LVM_STRUCT_VERSION) {
+               if (!lvm_pv_check_version(vg.pv[p])) {
                   ret = -LVM_EVG_READ_LVM_STRUCT_VERSION;
                   goto lvm_tab_vg_check_exist_end;
                }
