@@ -36,10 +36,8 @@
 int pv_check_volume ( char *dev_name, pv_t *pv) {
    int ret = FALSE;
 
-#ifdef DEBUG
    debug_enter ( "pv_check_volume -- CALLED  dev_name: \"%s\"  pv: %0X\n",
                  dev_name, ( uint) pv);
-#endif
 
    if ( dev_name == NULL ||
         pv_check_name ( dev_name) < 0 ||
@@ -47,8 +45,6 @@ int pv_check_volume ( char *dev_name, pv_t *pv) {
    else if ( pv_check_new ( pv) == TRUE ||
              vg_check_name ( pv->vg_name) == 0) ret = TRUE;
 
-#ifdef DEBUG
    debug_leave ( "pv_check_volume -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
