@@ -7,6 +7,7 @@
  * May,August,November 1998
  * December 1998
  * January,February 2000
+ * December 2001
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -45,6 +46,7 @@
  *    25/12/1888 - checked for pv_create_name_from_kdev_t() == NULL
  *                 (can happen in case /proc is not mounted)
  *    03/02/2000 - use debug_enter()/debug_leave()
+ *    19/12/2001 - avoid calling pv_flush()
  *
  */
 
@@ -67,11 +69,6 @@ int pv_read ( char *pv_name, pv_t **pv, int *open_errno) {
       goto pv_read_end;
    }
 
-   if ( pv_read_already_red ( pv_name) == FALSE && pv_flush ( pv_name) < 0) {
-      ret = -LVM_EPV_READ_PV_FLUSH;
-      goto pv_read_end;
-   }
-
    if ( ( pv_handle = open ( pv_name, O_RDONLY)) != -1) {
       if ( fstat ( pv_handle, &stat_b) == 0) {
          debug ( "pv_read -- going to read %s\n", pv_name);
@@ -99,7 +96,7 @@ int pv_read ( char *pv_name, pv_t **pv, int *open_errno) {
          strncpy ( (*pv)->pv_name, pv_name_ptr, sizeof ( (*pv)->pv_name) - 1);
          if ( strncmp ( (*pv)->id, LVM_ID, sizeof ( (*pv)->id)) != 0)
             ret = -LVM_EPV_READ_ID_INVALID;
-         else if ( (*pv)->version != LVM_STRUCT_VERSION)
+         else if (!lvm_pv_check_version(*pv))
             ret = -LVM_EPV_READ_LVM_STRUCT_VERSION;
          else if ( system_id_check_exported ( (*pv)->system_id) == TRUE)
             ret = -LVM_EPV_READ_PV_EXPORTED;
