@@ -1,10 +1,12 @@
 /*
  * tools/lib/pv_read_all_pv.c
  *
- * Copyright (C) 1997 - 1999  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March-May,October-November 1997
  * May,August,November 1998
+ * September 1999
+ * January 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -39,6 +41,12 @@
  *                 multiple MD entries according
  *    15/11/1998 - avoided pv_read'ing all partition special files, if
  *                 disk doesn't exist
+ *    02/09/1999 - avoided open optimization because it fails in non
+ *                 standard environments
+ *    22/09/1999 - added support for new partition identifier 0xDE
+ *    29/10/1999 - fixed possible free() bug
+ *    03/02/2000 - use debug_enter()/debug_leave()
+ *    17/02/2002 - use pv_get_size_ll() for library compatibility
  *
  */
 
@@ -54,7 +62,6 @@ int pv_read_all_pv ( pv_t ***pv, int reread) {
    int p_sav2 = 0;
    int pv_read_errno = 0;
    int ret = 0;
-   int tst = 0;
    char *dev_name = NULL;
    static int first = 0;
    struct partition partition;
@@ -62,10 +69,9 @@ int pv_read_all_pv ( pv_t ***pv, int reread) {
    static pv_t **pv_this = NULL;
    pv_t *pv_tmp = NULL;
    dir_cache_t *dir_cache = NULL;
+   struct stat statbuf;
 
-#ifdef DEBUG
-   debug ( "pv_read_all_pv -- CALLED\n");
-#endif
+   debug_enter ( "pv_read_all_pv -- CALLED\n");
 
    if ( pv == NULL ||
         ( reread != TRUE && reread != FALSE)) {
@@ -85,41 +91,31 @@ int pv_read_all_pv ( pv_t ***pv, int reread) {
    }
 
    if ( first == 0) {
-#ifdef DEBUG
          debug ( "pv_read_all_pv -- calling lvm_dir_cache\n");
-#endif
-      if ( ( cache_size = lvm_dir_cache ( &dir_cache)) < 1)
-         return -LVM_EPV_READ_ALL_PV_LVM_DIR_CACHE;
+      if ( ( cache_size = lvm_dir_cache ( &dir_cache)) < 1) {
+         ret = -LVM_EPV_READ_ALL_PV_LVM_DIR_CACHE;
+         goto pv_read_all_pv_end;
+      }
 
       np = 0;
       for ( n = 0; n < cache_size; n++) {
          dev_name = dir_cache[n].dev_name;
-
-#ifdef DEBUG
-         debug ( "pv_read_all_pv -- calling pv_read with \"%s\"\n",
+         debug ( "pv_read_all_pv -- calling stat with \"%s\"\n",
                   dev_name);
-#endif
-         if ( ( tst = open ( dev_name, O_RDONLY)) == -1) {
-            if ( MAJOR ( dir_cache[n].st_rdev) != MD_MAJOR &&
-                 MINOR ( dir_cache[n].st_rdev) % 16 == 0) {
-               n += 15;
-               continue;
-            }
-         } else close ( tst);
+         if ( stat ( dev_name, &statbuf) == -1) continue;
 
          pv_read_errno = 0;
          if ( ( ret = pv_read ( dev_name, &pv_tmp, &pv_read_errno)) == 0 ||
               ret == -LVM_EPV_READ_MD_DEVICE ||
               ret == -LVM_EPV_READ_PV_EXPORTED) {
             memset ( &partition, 0, sizeof ( partition));
-            if ( pv_get_size ( dev_name, &partition) < 0) continue;
+            if ( pv_get_size_ll ( dev_name, &partition) < 0ll) continue;
             if ( partition.sys_ind != 0 && 
-                 partition.sys_ind != LVM_PARTITION) continue;
+                 partition.sys_ind != LVM_PARTITION &&
+                 partition.sys_ind != LVM_NEW_PARTITION) continue;
             if ( pv_check_volume ( dev_name, pv_tmp) == TRUE) {
-#ifdef DEBUG
                 debug ( "pv_read_all_pv: allocating for %s %s\n",
                          pv_tmp->pv_name, pv_tmp->vg_name);
-#endif
                pv_this_sav = pv_this;
                if ( ( pv_this = realloc ( pv_this,
                                           ( np + 2) * sizeof ( pv_t*)))
@@ -131,7 +127,7 @@ int pv_read_all_pv ( pv_t ***pv, int reread) {
                      free ( pv_this_sav[p]);
                   ret = -LVM_EPV_READ_ALL_PV_MALLOC;
                   goto pv_read_all_pv_end;
-               }
+               } else pv_this_sav = NULL;
                if ( ( pv_this[np] = malloc ( sizeof ( pv_t))) == NULL) {
                   fprintf ( stderr, "malloc error in %s [line %d]\n",
                                     __FILE__, __LINE__);
@@ -157,7 +153,7 @@ int pv_read_all_pv ( pv_t ***pv, int reread) {
 #endif
       }
       first = 1;
-      ret = 0;
+      if ( np > 0 || ret == -LVM_EPV_READ_READ) ret = 0;
    }
 
 #ifdef DEBUG
@@ -166,36 +162,33 @@ int pv_read_all_pv ( pv_t ***pv, int reread) {
 #endif
 
    /* FIXME: this doesn't work perfect in case of MD inactivity */
-   /* check for MD and clear out SCSI, IDE, ... doubles */
+   /* clear out SCSI, IDE, ... doubles */
    for ( p = 0; pv_this != NULL && pv_this[p] != NULL; p++) {
-      if ( MAJOR ( pv_this[p]->pv_dev) == MD_MAJOR) {
-         p_sav1 = p;
-         for ( p = 0; pv_this[p] != NULL; p++) {
-            if ( pv_this[p_sav1] != pv_this[p] && 
-                 strcmp ( pv_this[p_sav1]->vg_name, pv_this[p]->vg_name) == 0) {
-               if ( pv_this[p_sav1]->pv_dev != pv_this[p]->pv_dev) {
-                  free ( pv_this[p]);
+      p_sav1 = p;
+      for ( p = 0; pv_this[p] != NULL; p++) {
+         if ( pv_this[p_sav1] != pv_this[p] && 
+              strcmp ( pv_this[p_sav1]->vg_name, pv_this[p]->vg_name) == 0) {
+            if ( pv_this[p_sav1]->pv_dev == pv_this[p]->pv_dev) {
+               free ( pv_this[p]);
+               pv_this[p] = NULL;
+               if ( p < np) np--;
+               p_sav2 = p - 1;
+               p++;
+               for ( ;  pv_this[p] != NULL; p++) {
+                  pv_this[p-1] = pv_this[p];
                   pv_this[p] = NULL;
-                  if ( p < np) np--;
-                  p_sav2 = p - 1;
-                  p++;
-                  for ( ;  pv_this[p] != NULL; p++) {
-                     pv_this[p-1] = pv_this[p];
-                     pv_this[p] = NULL;
-                  }
-                  p = p_sav2;
                }
+               p = p_sav2;
             }
          }
-         p = p_sav1;
       }
+      p = p_sav1;
    }
 
    *pv = pv_this;
 
 pv_read_all_pv_end:
-#ifdef DEBUG
-   debug ( "pv_read_all_pv -- LEAVING with ret: %d\n", ret);
-#endif
+
+   debug_leave ( "pv_read_all_pv -- LEAVING with ret: %d\n", ret);
    return ret;
 }
