@@ -1,12 +1,13 @@
 /*
  * tools/lib/pv_read_all_pv_of_vg.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March-May,October-November 1997
  * May,August,November 1998
  * January,March,April,September,October 2000
  * February,November 2001
+ * January 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -37,6 +38,7 @@
  *    07/02/2001 - fixed multiple access path avoidance problem
  *                 leading to removed but valid PV structure
  *    22/11/2001 - support non sequential PV numbers
+ *    01/14/2002 - fixed contiguous PV array bug (MG)
  *
  */
 
@@ -141,11 +143,14 @@ uuid_check_end:
 
       /* avoid multiple access pathes */
       if ( pv_this) {
+          int last_one;
+
 	  for ( p = 0; p < np; p++) {
-	      /* avoid multiple access pathes for now (2.4.0-test8)
+	      /* avoid multiple access paths for now (2.4.0-test8)
 		 and MD covered pathes as well */
               if ( pv_this[p] == NULL) continue;
 	      for ( i = 0; i < np; i++) {
+                  if ( pv_this[p] == NULL) continue;
                   if ( pv_this[i] == NULL || p == i) continue;
 		  if ( strncmp ( pv_this[p]->vg_name, vg_name, NAME_LEN) == 0) {
 		      if ( pv_this[i]->pv_number == pv_this[p]->pv_number &&
@@ -161,20 +166,19 @@ uuid_check_end:
 	      }
 	  }
           /* make array contiguous again */
-          for ( i = 0; i < np - 2; i++) {
-             if ( pv_this[i] == NULL) {
-                /* ensure we don't have a sequence of NULLs */
-                if ( pv_this[i+1] == NULL) {
-                   int j = i + 1;
-                   while ( pv_this[j] == NULL && j < np - 1) j++;
-                   if ( j < np - 1) pv_this[i+1] = pv_this[j];
-                }
-                pv_this[i] = pv_this[i+1];
-                pv_this[i+1] = NULL;
+          /* last one that wasn't NULL */
+          last_one = -1;
+          for ( i = 0; i < np; i++) {
+             if ( pv_this[i] != NULL) {
+                 last_one++;
+                 /* we only need this when last_one and i differ */
+                 if (last_one < i) {
+                    pv_this[last_one]=pv_this[i];
+                    pv_this[i]=NULL;
+                 }
              }
-          }
-          np = 0;
-          while ( pv_this[np] != NULL) np++;
+         }
+         np = last_one+1;
       }
 
       /* now we only have pointers to single access path PVs
