@@ -7,7 +7,8 @@
  * September,October 1999
  * January 2000
  * April 2001
- * Sepetember 2002
+ * September 2002
+ * May 2003
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -37,6 +38,7 @@
  *    08/02/2000 - use debug_enter()/debug_leave()
  *    09/04/2001 - cleaned up debug output (Andreas Dilger)
  *    25/09/2002 - array dereference bug fixed in vg_check_active_all_vg()
+ *    26/05/2003 - avoid memory leak in vg_check_active() [Andrew Patterson]
  *
  */
 
@@ -52,6 +54,7 @@ int vg_check_active ( char *vg_name) {
    else if ( ( ret = vg_status ( vg_name, &vg)) == 0) {
       if ( vg->vg_status & VG_ACTIVE) ret = TRUE;
       else                            ret = FALSE;
+      if (vg) free(vg);
    }
 
    debug_leave ( "vg_check_active -- LEAVING with ret: %d\n", ret);
