@@ -1,12 +1,13 @@
 /*
  * tools/lib/vg_check_exist.c
  *
- * Copyright (C) 1997 - 2001  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March, November 1997
  * February,May,September 1999
  * January 2000
  * April,May 2001
+ * February 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -38,6 +39,8 @@
  *    09/04/2001 - cleaned up debug output (Andreas Dilger)
  *    22/05/2001 - fixed pv cache flush related bug causing invalid
  *                 pointer accesses in vg_check_exist()
+ *    07/02/2002 - vg_check_exist_all_vg() returns all vg_names seen now
+ *                 event though their PVs might not be all present
  *
  */
 
@@ -63,7 +66,7 @@ int vg_check_exist ( char *vg_name) {
                   pv[p]->vg_name[strlen(pv[p]->vg_name)-strlen(EXPORTED)] = 0;
                if ( strcmp ( vg_name, pv[p]->vg_name) == 0) {
                   pv_count++;
-                  if ( pv[p]->version != LVM_STRUCT_VERSION) {
+                  if (!lvm_pv_check_version(pv[p])) {
                      ret = -LVM_EVG_READ_LVM_STRUCT_VERSION;
                      break;
                   }
@@ -123,40 +126,34 @@ char **vg_check_exist_all_vg ( void) {
          for ( v = 0; v < nv && vg_name_ptr[v] != NULL; v++)
             if ( strcmp ( pv[p]->vg_name, vg_name_ptr[v]) == 0) break;
          if ( v < nv) continue;
-            debug ( "vg_check_exist_all_vg -- before vg_check_exist ( %s)\n",
-                    pv[p]->vg_name);
-         if ( ( ret = vg_check_exist ( pv[p]->vg_name)) == TRUE) {
-            debug ( "vg_check_exist_all_vg -- HIT vg_name: %s\n",
-                    pv[p]->vg_name);
-            vg_name_ptr_sav = vg_name_ptr;
-            if ( ( vg_name_ptr =
-                      realloc ( vg_name_ptr,
-                                ( nv + 2) * sizeof ( char*))) == NULL) {
-               fprintf ( stderr, "realloc error in %s [line %d]\n",
-                                 __FILE__, __LINE__);
-               if ( vg_name_ptr_sav != NULL) {
-                  for ( v = 0; vg_name_ptr_sav[v] != NULL; v++)
-                     free ( vg_name_ptr_sav[v]);
-                  free ( vg_name_ptr_sav);
-               }
-               goto vg_check_exist_all_vg_end;
-            } else vg_name_ptr_sav = NULL;
-            vg_name_ptr[nv+1] = NULL;
-            if ( ( vg_name_ptr[nv] =
-                   malloc ( strlen ( pv[p]->vg_name) + 1)) == NULL) {
-               fprintf ( stderr, "malloc error in %s [line %d]\n",
-                                 __FILE__, __LINE__);
-               for ( v = 0; vg_name_ptr[v] != NULL; v++)
-                  free ( vg_name_ptr[v]);
-               free ( vg_name_ptr);
-               vg_name_ptr = NULL;
-               goto vg_check_exist_all_vg_end;
+         vg_name_ptr_sav = vg_name_ptr;
+         if ( ( vg_name_ptr =
+                   realloc ( vg_name_ptr,
+                             ( nv + 2) * sizeof ( char*))) == NULL) {
+            fprintf ( stderr, "realloc error in %s [line %d]\n",
+                              __FILE__, __LINE__);
+            if ( vg_name_ptr_sav != NULL) {
+               for ( v = 0; vg_name_ptr_sav[v] != NULL; v++)
+                  free ( vg_name_ptr_sav[v]);
+               free ( vg_name_ptr_sav);
             }
-            strcpy ( vg_name_ptr[nv], pv[p]->vg_name);
-            debug ( "vg_check_exist_all_vg -- vg_name_ptr[%d]: %s\n",
-                     nv, vg_name_ptr[nv]);
-            nv++;
+            goto vg_check_exist_all_vg_end;
+         } else vg_name_ptr_sav = NULL;
+         vg_name_ptr[nv+1] = NULL;
+         if ( ( vg_name_ptr[nv] =
+                malloc ( strlen ( pv[p]->vg_name) + 1)) == NULL) {
+            fprintf ( stderr, "malloc error in %s [line %d]\n",
+                              __FILE__, __LINE__);
+            for ( v = 0; vg_name_ptr[v] != NULL; v++)
+               free ( vg_name_ptr[v]);
+            free ( vg_name_ptr);
+            vg_name_ptr = NULL;
+            goto vg_check_exist_all_vg_end;
          }
+         strcpy ( vg_name_ptr[nv], pv[p]->vg_name);
+         debug ( "vg_check_exist_all_vg -- vg_name_ptr[%d]: %s\n",
+                  nv, vg_name_ptr[nv]);
+         nv++;
       }
    }
 
