@@ -1,9 +1,11 @@
 /*
  * tools/lib/vg_check_pe_size.c
  *
- * Copyright (C) 1997 - 1999  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * May 1997
+ * October 1999
+ * January 2000
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -23,25 +25,25 @@
  *
  */
 
+/*
+ * Changelog
+ *
+ *    05/10/1999 - simplified power of 2 check
+ *    08/02/2000 - use debug_enter()/debug_leave()
+ *
+ */
+
 #include <liblvm.h>
 
 int vg_check_pe_size ( ulong pe_size) {
-   int exp2 = -1;
-   ulong pe_size_this;
+   int ret = 0;
 
-#ifdef DEBUG
-   debug ( "vg_check_check_pe_size -- CALLED\n");
-#endif
+   debug_enter ( "vg_check_check_pe_size -- CALLED\n");
 
-   pe_size_this = pe_size;
-   while ( ( pe_size_this >>= 1) > 0) exp2++;
+   if ( pe_size < LVM_MIN_PE_SIZE ||
+        pe_size > LVM_MAX_PE_SIZE ||
+        ( pe_size & ( pe_size - 1)) != 0 ) ret = -LVM_EVG_CHECK_PE_SIZE;
 
-   if ( pe_size >= LVM_MIN_PE_SIZE &&
-        pe_size <= LVM_MAX_PE_SIZE &&
-        ( pe_size % ( 1<<exp2)) == 0 ) return 0;
-
-#ifdef DEBUG
-   debug ( "vg_check_check_pe_size -- LEAVING\n");
-#endif
-   return -LVM_EVG_CHECK_PE_SIZE;
+   debug_leave ( "vg_check_check_pe_size -- LEAVING with ret: %d\n", ret);
+   return ret;
 }
