@@ -1,7 +1,7 @@
 /*
  * tools/lib/vg_free.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * June 1998
  * January 2000
@@ -38,15 +38,11 @@ int vg_free ( vg_t *vg, int all) {
    int p = 0;
    int ret = 0;
 
-#ifdef DEBUG
    debug_enter ( "vg_free -- CALLED\n");
-#endif
 
    if ( vg == NULL || ( all != TRUE && all != FALSE)) ret = -LVM_EPARAM;
    else {
-#ifdef DEBUG
       debug ( "vg_free -- entering PV loop\n");
-#endif
       for ( p = 0; p < vg->pv_cur; p++) {
          if ( vg->pv[p] != NULL) {
             if ( vg->pv[p]->pe != NULL) free ( vg->pv[p]->pe);
@@ -54,9 +50,7 @@ int vg_free ( vg_t *vg, int all) {
             vg->pv[p] = NULL;
          }
       }
-#ifdef DEBUG
       debug ( "vg_free -- entering LV loop\n");
-#endif
       for ( l = 0; l < vg->lv_max; l++) {
          if ( vg->lv[l] != NULL) {
             if ( vg->lv[l]->lv_current_pe != NULL)
@@ -68,8 +62,6 @@ int vg_free ( vg_t *vg, int all) {
       if ( all == TRUE) free ( vg);
    }
 
-#ifdef DEBUG
    debug_leave ( "vg_free -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
