@@ -129,8 +129,10 @@ int vg_setup_for_merge ( vg_t *vg_to, vg_t *vg_from) {
                              vg_to->lv[l1]->lv_name) == 0) {
                   l2 = vg_to_lv_index + 1;
                   do {
-                     sprintf ( lv_name_this, LVM_DIR_PREFIX "%s/lvol%d",
-                               vg_to->vg_name, l2);
+                     memset ( lv_name_this, 0, sizeof ( lv_name_this));
+                     snprintf ( lv_name_this, sizeof ( lv_name_this) - 1,
+                                              LVM_DIR_PREFIX "%s/lvol%d",
+                                              vg_to->vg_name, l2);
                      l2++;
                   } while ( lvm_tab_lv_check_exist ( lv_name_this) == TRUE);
                   strcpy ( vg_to->lv[vg_to_lv_index]->lv_name, lv_name_this);
