@@ -1,12 +1,13 @@
 /*
  * tools/lvchange.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2001  Heinz Mauelshagen, Sistina Software
  *
  * May,October 1997
  * April-June,August 1998
  * February,July,August,October 1999
  * February,November 2000
+ * January,March,July 2001
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +43,9 @@
  *    06/10/1999 - implemented support for long options
  *    15/02/2000 - use lvm_error()
  *    07/11/2000 - used LVM_VG_NAME environment variable
+ *    23/01/2001 - added call to lvm_init (JT)
+ *    19/03/2001 - Fix some typos in messages
+ *    25/07/2001 - avoid misleading "(null)" in error message (AGK)
  *
  */
 
@@ -74,18 +78,12 @@ int main ( int argc, char **argv)
    long read_ahead = 0;
    int ret = 0;
    char *lv_name = NULL;
-#ifdef DEBUG
-   char *options = "A:a:C:dh?p:r:v";
-#else
-   char *options = "A:a:C:h?p:r:v";
-#endif
+   char *options = "A:a:C:h?p:r:v" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
       { "autobackup", required_argument, NULL, 'A'},
       { "available",  required_argument, NULL, 'a'},
       { "contiguous", required_argument, NULL, 'C'},
-#ifdef DEBUG
-      { "debug",      no_argument,       NULL, 'd'},
-#endif
+      DEBUG_LONG_OPTION
       { "help",       no_argument,       NULL, 'h'},
       { "permission", required_argument, NULL, 'p'},
       { "readahead",  required_argument, NULL, 'r'},
@@ -96,9 +94,9 @@ int main ( int argc, char **argv)
    lv_t *lv = NULL;
    vg_t *vg = NULL;
 
+   /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
-   SUSER_CHECK;
    LVMTAB_CHECK;
 
    while ( ( c = getopt_long ( argc, argv, options,
@@ -146,15 +144,7 @@ int main ( int argc, char **argv)
             return LVM_EINVALID_CMD_LINE;
             break;
 
-#ifdef DEBUG
-         case 'd':
-            if ( opt_d > 0) {
-               fprintf ( stderr, "%s -- d option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
-            opt_d++;
-            break;
-#endif
+         DEBUG_HANDLE_CASE_D;
 
          case 'h':
          case '?':
@@ -165,10 +155,8 @@ int main ( int argc, char **argv)
                      "\t[-A/--autobackup y/n]\n"
                      "\t[-a/--available y/n]\n"
                      "\t[-C/--contiguous y/n]\n"
-#ifdef DEBUG
-                     "\t[-d/--debug]\n"
-#endif
-                     "\t[-h/-?/--help]\n"
+                     DEBUG_HELP
+                     "\t[-h/--help]\n"
                      "\t[-p/--permission r/rw]\n"
                      "\t[-r/--readahead ReadAheadSectors]\n"
                      "\t[-v/--verbose]\n"
@@ -247,6 +235,12 @@ int main ( int argc, char **argv)
       lv_name = argv[optind];
 
       LVM_CHECK_DEFAULT_VG_NAME ( lv_name, buffer, NAME_LEN);
+      if ( lv_name == NULL) {
+         fprintf ( stderr, "%s -- a path needs supplying for "
+                           "logical volume argument \"%s\"\n\n",
+                           cmd, argv[optind]);
+         continue;
+      }
 
       if ( opt_v > 0) printf ( "%s -- checking logical volume name\n", cmd);
       if ( lv_check_name ( lv_name) < 0) {
@@ -413,7 +407,7 @@ int main ( int argc, char **argv)
             doit_sum++;
             if ( lv_stat & LV_ACTIVE) lv->lv_status |= LV_ACTIVE;
             else                      lv->lv_status &= ~LV_ACTIVE;
-            if ( opt_v > 0) printf ( "%s -- changing availiability of "
+            if ( opt_v > 0) printf ( "%s -- changing availability of "
                                      "logical volume \"%s\"\n",
                                      cmd, lv_name);
             if ( ( ret = ioctl ( blkdev, LV_SET_STATUS,
@@ -430,7 +424,7 @@ int main ( int argc, char **argv)
                return LVM_ELVCHANGE_LV_SET_STATUS;
             }
          } else {
-            printf ( "%s -- availiability of logical volume \"%s\" doesn't "
+            printf ( "%s -- availability of logical volume \"%s\" doesn't "
                      "have to be changed\n",
                       cmd, lv_name);
          }
