@@ -9,6 +9,7 @@
  * February,July,September,November 2000
  * January,March,June,July 2001
  * February 2002
+ * August 2003
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -79,6 +80,8 @@
  *    25/07/2001 - lv_path->lv_name in err mesg (AGK)
  *    07/02/2002 - fixes for > 1TB support
  *    14/02/2002 - use lvm_check_number_ll() for (long long) numbers
+ *    21/08/2003 - fix bug preventing to specify an MD on the
+ *                 command line [Dustin Cooper]
  *
  */
 
@@ -699,7 +702,9 @@ int main ( int argc, char **argv) {
                       cmd, pv_allowed[pa], vg_name);
             usage ( LVM_ELVCREATE_PV_CHECK_IN_VG);
          }
-         if ( pv_read ( pv_allowed[pa], &pv, NULL) < 0) {
+         ret = pv_read ( pv_allowed[pa], &pv, NULL);
+         if ( ret < 0 &&
+              ret != -LVM_EPV_READ_MD_DEVICE) {
             fprintf ( stderr, "%s -- couldn't read physical volume \"%s\"\n\n",
                               cmd, pv_allowed[pa]);
             return LVM_ELVCREATE_PV_READ;
