@@ -1,11 +1,12 @@
 /*
  * tools/lvm_user.h
  *
- * Copyright (C) 1997 - 2001  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March 1997
  * May 1998
  * January 1999
+ * February 2002
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +32,7 @@
  *    01/01/1999 - ported to libc6
  *    01/22/1999 - added exit states of commands
  *    15/09/1999 - enhanced check with lvm_check_kernel_lvmtab_consistency()
+ *    13/02/2002 - defined opt_ignore for pvmove
  *
  */
 
@@ -57,6 +59,9 @@
 
 char *lvm_version = "Logical Volume Manager "LVM_RELEASE_NAME"\nHeinz Mauelshagen, Sistina Software  "LVM_RELEASE_DATE;
 
+/* pvmove */
+int opt_ignore = 0;
+
 #ifdef DEBUG
 #	define DEBUG_HELP           "\t[-d/--debug]\n"
 #	define DEBUG_HELP_2         "[-d|--debug] "
@@ -74,8 +79,8 @@ char *lvm_version = "Logical Volume Manager "LVM_RELEASE_NAME"\nHeinz Mauelshage
 #define	LVMFILE_CHECK( chkfile) { \
    int file = -1; \
    if ( ( file = open ( chkfile, O_RDONLY)) == -1) { \
-      fprintf ( stderr, "%s -- ERROR: \"%s\" doesn't exist; " \
-                        "please run vgscan\n\n", \
+      fprintf ( stderr, "%s -- ERROR: \"%s\" doesn't exist or is unreadable; " \
+                        "you may need to run vgscan\n\n", \
                         cmd, chkfile); \
       return LVM_ELVMTAB; \
    } else close ( file); \
@@ -439,8 +444,6 @@ char *lvm_version = "Logical Volume Manager "LVM_RELEASE_NAME"\nHeinz Mauelshage
 #define	LVM_EVGCHANGE_VG_CFGBACKUP_LVMTAB		6
 #define	LVM_EVGCHANGE_VG_CREATE_DIR_AND_GROUP_NODES	7
 #define	LVM_EVGCHANGE_VG_REMOVE_DIR_AND_GROUP_NODES	8
-#define	LVM_EVGCHANGE_LV_SETUP_COW_TABLE_FOR_CREATE	9
-#define	LVM_EVGCHANGE_LV_READ_COW_TABLE			10
 
 /* vgck */
 #define	LVM_EVGCK_CHECK_ERRORS			1
@@ -590,6 +593,7 @@ char *lvm_version = "Logical Volume Manager "LVM_RELEASE_NAME"\nHeinz Mauelshage
 #define LVM_EVGSCAN_NO_DEV			5
 #define LVM_EVGSCAN_VG_WRITE			6
 #define LVM_EVGSCAN_DEV_REUSE			7
+#define LVM_EVGSCAN_LV_RELEASE			8
 
 /* vgsplit */
 #define LVM_EVGSPLIT_VG_CHECK_NAME		1
