@@ -1,10 +1,11 @@
 /*
  * tools/lvmdiskscan.c
  *
- * Copyright (C) 1997 - 1999  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * May,June,November 1998
- * February-March 1999
+ * February-March,July-October 1999
+ * February 2002
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,15 +27,31 @@
 /*
  * Changelog
  *
- *   16/11/1998 - avoided checking partition special files, if
- *                disk doesn't exist
- *   20/02/1999 - supported additional BSD partition type identifiers
- *   15/03/1999 - avoided LVMTAB_CHECK
- *   17/03/1999 - avoided loop device support
+ *    16/11/1998 - avoided checking partition special files, if
+ *                 disk doesn't exist
+ *    20/02/1999 - supported additional BSD partition type identifiers
+ *    15/03/1999 - avoided LVMTAB_CHECK
+ *    17/03/1999 - avoided loop device support
+ *    17/07/1999 - fixed bug: MD was increased instead in case of NBD
+ *               - added LVM/free info in case of whole disk
+ *    15/08/1999 - fixed DAC960 bug
+ *    02/09/1999 - avoided open optimization because it fails in non
+ *                 standard environments
+ *    22/09/1999 - added support for new partition identifier 0xDE
+ *    06/10/1999 - implemented support for long options
+ *    03/11/1999 - corrected wrong type of st_rdev from short to dev_t
+ *                 and wromg partition count
+ *                 (Thanks to Thomas Fehr <fehr@suse.de>)
+ *    23/01/2001 - added call to lvm_init (JT)
+ *    06/02/2002 - cope with changed pv_get_size() return cast
+ *    07/02/2002 - fixes for > 1TB support
+ *    17/02/2002 - use pv_get_size_ll() for library compatibility
  *
  */
 
 #include <lvm_user.h>
+#define	LVM_WHOLE_DISK( a) \
+   (MAJOR(a) + ( MINOR ( a) - ( MINOR ( a) % lvm_partition_count ( a))))
 
 char *cmd = NULL;
 
@@ -42,11 +59,11 @@ char *cmd = NULL;
 int opt_d = 0;
 #endif
 
+
 int main ( int argc, char **argv)
 {
-   short st_rdev = -1;
+   dev_t st_rdev = 0;
    int c = 0;
-   int in = 0;
    int dir_cache_size = 0;
    int len = 0;
    int maxlen = 0;
@@ -60,47 +77,42 @@ int main ( int argc, char **argv)
    int n_nbd_devices = 0;
    int n_partitions = 0;
    int p = 0;
-   int size = 0;
+   long long pv_size = 0;
+   ulong size = 0;
    int tst = -1;
    char *dummy = NULL;
    char fmt[32] = { 0, };
-#ifdef DEBUG
-   char *options = "dh?lv";
-#else
-   char *options = "h?lv";
-#endif
+   char *options = "h?lv" DEBUG_SHORT_OPTION;
+   struct option long_options[] = {
+      DEBUG_LONG_OPTION
+      { "help",         no_argument, NULL, 'h'},
+      { "lvmpartition", no_argument, NULL, 'l'},
+      { "verbose",      no_argument, NULL, 'v'},
+      { NULL, 0, NULL, 0}
+   };
    struct partition part;
    dir_cache_t *dir_cache = NULL;
+   pv_t *pv = NULL;;
 
+   /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
-   SUSER_CHECK;
-
-   while ( ( c = getopt ( argc, argv, options)) != EOF) {
+   while ( ( c = getopt_long ( argc, argv, options,
+                               long_options, NULL)) != EOF) {
       switch ( c) {
-#ifdef DEBUG
-         case 'd':
-            if ( opt_d > 0) {
-               fprintf ( stderr, "%s -- d option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
-            opt_d++;
-            break;
-#endif
+         DEBUG_HANDLE_CASE_D;
 
          case 'h':
          case '?':
-            printf ( "\n%s\n\n%s -- Physical Volume Scan\n\n"
+            printf ( "\n%s (IOP %d)\n\n%s -- Physical Volume Scan\n\n"
                      "Synopsis:\n"
                      "---------\n\n"
                      "%s\n"
-#ifdef DEBUG
-                     "\t[-d]\n"
-#endif
-                     "\t[-h/?]\n"
-                     "\t[-l]\n"
-                     "\t[-v]\n\n",
-                     lvm_version, cmd, cmd);
+                     DEBUG_HELP
+                     "\t[-h/--help]\n"
+                     "\t[-l/--lvmpartition]\n"
+                     "\t[-v/--verbose]\n\n",
+                     lvm_version, LVM_LIB_IOP_VERSION,  cmd, cmd);
             return 0;
             break;
 
@@ -143,38 +155,46 @@ int main ( int argc, char **argv)
       len = strlen ( dir_cache[p].dev_name);
       if ( maxlen < len) maxlen = len;
    }
-   sprintf ( fmt, "%s%d%s ", "%s -- %-", maxlen, "s [%14s]");
+   memset ( fmt, 0, sizeof ( fmt));
+   snprintf ( fmt, sizeof ( fmt) - 1,
+                   "%s%d%s ", "%s -- %-", maxlen, "s [%14s]");
 
    if ( opt_l > 0) printf ( "%s -- only showing LVM partitions/disks...\n",
                             cmd);
    for ( p = 0; p < dir_cache_size; p++) {
       if ( ( tst = open ( dir_cache[p].dev_name, O_RDONLY)) == -1) {
-         if ( lvm_check_partitioned_dev ( dir_cache[p].st_rdev) == TRUE &&
-              MINOR ( dir_cache[p].st_rdev) % 16 == 0) {
-            p += 15;
-            continue;
-         }
-      } else close ( tst);
-
-      if ( st_rdev > -1 && ( ( MINOR ( st_rdev) & 0xF0) ==
-           ( MINOR ( dir_cache[p].st_rdev) & 0xF0))) continue;
-      else st_rdev = -1;
-
-      if ( ( size = pv_get_size ( dir_cache[p].dev_name,
-                                  &part)) < 0) continue;
-
-      if ( lvm_check_partitioned_dev ( dir_cache[p].st_rdev) == TRUE &&
-           ( MINOR ( dir_cache[p].st_rdev) % 16 == 0) &&
-           ( in = open ( dir_cache[p].dev_name, O_RDONLY)) != -1) {
-         n_disks++;
-         if ( in != -1) {
-            close ( in);
-            in = -1;
+         continue;
+      } else {
+         close ( tst);
+         if ( lvm_check_partitioned_dev ( dir_cache[p].st_rdev) == TRUE) {
+            if ( lvm_check_whole_disk_dev ( dir_cache[p].st_rdev) == TRUE)
+               n_disks++;
+            else
+               n_partitions++;
          }
       }
 
-      n_partitions++;
-      if ( opt_l > 0 && part.sys_ind != LVM_PARTITION) continue;
+      /* Skip partition entries in the directory cache in
+         case we found a LVM whole disk before */
+      if ( st_rdev > 0 && LVM_WHOLE_DISK ( st_rdev) ==
+           LVM_WHOLE_DISK ( dir_cache[p].st_rdev)) continue;
+      else st_rdev = 0;
+
+      pv_size = pv_get_size_ll ( dir_cache[p].dev_name, &part);
+      if ( pv_size < 0LL) continue;
+      if ( pv_size > LVM_MAX_SIZE) {
+         fprintf ( stderr, "%s -- size of \"%s\" is larger than 2TB\n\n",
+                           dir_cache[p].dev_name, cmd);
+         continue;
+      }
+      size = pv_size;
+
+      if ( pv_check_partitioned_whole ( dir_cache[p].dev_name ) )
+	  continue;
+	  
+      if ( opt_l > 0 &&
+           part.sys_ind != LVM_PARTITION &&
+           part.sys_ind != LVM_NEW_PARTITION) continue;
 
       if ( part.sys_ind != 0 &&
            pv_check_part ( dir_cache[p].dev_name) < 1) continue;
@@ -182,8 +202,14 @@ int main ( int argc, char **argv)
       printf ( fmt, cmd, dir_cache[p].dev_name,
                ( dummy = lvm_show_size ( size / 2, SHORT)));
       free ( dummy); dummy = NULL;
+
       if ( part.sys_ind == 0) {
-         n_partitions--;
+         if ( pv_read ( dir_cache[p].dev_name, &pv, NULL) == 0) {
+            if ( pv_check_new ( pv) == TRUE) printf ( "new ");
+            else printf ( "USED ");
+            printf ( "LVM ");
+         } else printf ( "free ");
+         
 #ifdef LOOP_MAJOR
          if ( MAJOR ( dir_cache[p].st_rdev) == LOOP_MAJOR) {
             n_loop_devices++;
@@ -193,12 +219,12 @@ int main ( int argc, char **argv)
 #ifdef MD_MAJOR
          if ( MAJOR ( dir_cache[p].st_rdev) == MD_MAJOR) {
             n_md_devices++;
-            printf ( "multiple device");
+            printf ( "meta device");
          } else
 #endif
 #ifdef NBD_MAJOR
          if ( MAJOR ( dir_cache[p].st_rdev) == NBD_MAJOR) {
-            n_md_devices++;
+            n_nbd_devices++;
             printf ( "network block device");
          } else
 #endif
@@ -209,7 +235,7 @@ int main ( int argc, char **argv)
          }
       } else {
          if ( opt_l == 0) {
-            if ( MINOR ( dir_cache[p].st_rdev) % 16 > 4)
+            if ( lvm_check_extended_partition ( dir_cache[p].st_rdev) == TRUE)
                printf ( "Extended ");
             else if ( part.sys_ind != DOS_EXTENDED_PARTITION)
                printf ( "Primary  ");
@@ -239,7 +265,8 @@ int main ( int argc, char **argv)
          else if ( part.sys_ind == BSDI_PARTITION)
             printf ( "BSDI");
 #endif
-         else if ( part.sys_ind == LVM_PARTITION) {
+         else if ( part.sys_ind == LVM_PARTITION ||
+                   part.sys_ind == LVM_NEW_PARTITION) {
             n_lvm_pvs++;
             if ( opt_l == 0) printf ( "LVM partition");
          } else if ( part.sys_ind == DOS_EXTENDED_PARTITION)
@@ -255,7 +282,7 @@ int main ( int argc, char **argv)
             printf ( "Windows98 extended partition");
 #endif
       }
-      if ( opt_l == 0 && part.sys_ind != 0) printf ( " [0x%X]\n", part.sys_ind);
+      if ( opt_l == 0 && part.sys_ind != 0) printf(" [0x%02X]\n", part.sys_ind);
       else             putchar ( '\n');
    }
 
