@@ -32,6 +32,7 @@
  *    03/11/1999 - implemented stdout support
  *                 (Thanks to Torsten Neumann <torsten@londo.rhein-main.de>)
  *    15/02/2000 - use lvm_error()
+ *    23/01/2001 - added call to lvm_init (JT)
  *
  */
 
@@ -49,15 +50,9 @@ int main ( int argc, char **argv) {
    int opt_v = 0;
    int ret = 0;
    int v = 0;
-#ifdef DEBUG
-   char *options = "dh?v";
-#else
-   char *options = "h?v";
-#endif
+   char *options = "h?v" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
-#ifdef DEBUG
-      { "debug",   no_argument, NULL, 'd'},
-#endif
+      DEBUG_LONG_OPTION
       { "help",    no_argument, NULL, 'h'},
       { "verbose", no_argument, NULL, 'v'},
       { NULL, 0, NULL, 0}
@@ -68,23 +63,15 @@ int main ( int argc, char **argv) {
    vg_t *vg = NULL;
    FILE *log = NULL;
 
+   /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
-   SUSER_CHECK;
    LVMTAB_CHECK;
 
    while ( ( c = getopt_long ( argc, argv, options,
                                long_options, NULL)) != EOF) {
       switch ( c) {
-#ifdef DEBUG
-         case 'd':
-            if ( opt_d > 0) {
-               fprintf ( stderr, "%s -- d option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
-            opt_d++;
-            break;
-#endif
+         DEBUG_HANDLE_CASE_D;
 
          case 'h':
          case '?':
@@ -93,10 +80,8 @@ int main ( int argc, char **argv) {
                      "Synopsis:\n"
                      "---------\n\n"
                      "%s\n"
-#ifdef DEBUG
-                     "\t[-d/--debug]\n"
-#endif
-                     "\t[-h/-?/--help]\n"
+                     DEBUG_HELP
+                     "\t[-h/--help]\n"
                      "\t[-v/--verbose]\n"
                      "\t[LogFilePath]\n\n",
                      lvm_version, LVM_LIB_IOP_VERSION,  cmd, cmd);
@@ -161,7 +146,7 @@ int main ( int argc, char **argv) {
                               vg->lv[l]->lv_name,
                               vg->lv[l]->lv_allocated_le);
                for ( le = 0; le < vg->lv[l]->lv_allocated_le; le++) {
-                  fprintf ( log, "%lu %lu %lu\n",
+                  fprintf ( log, "%lu %u %u\n",
                                  le,
                                  vg->lv[l]->lv_current_pe[le].reads,
                                  vg->lv[l]->lv_current_pe[le].writes);
