@@ -1,12 +1,13 @@
 /*
  * tools/pvcreate.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March, October-November 1997
  * May,June,September 1998
  * January,June,September,October 1999
  * February 2000
+ * February 2002
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,6 +48,11 @@
  *    23/01/2001 - added call to lvm_init (JT)
  *    14/02/2001 - tidied usage message and options
  *    09/04/2001 - Remove check_partitioned_whole into pv_get_size.c
+ *    06/02/2002 - cope with changed pv_get_size() return cast
+ *    07/02/2002 - added size option
+ *               - fixes for > 1TB support
+ *    15/02/2002 - further > 1 TB additions
+ *    17/02/2002 - use pv_get_size_ll() for library compatibility
  *
  */
 
@@ -72,9 +78,10 @@ static void usage(int ret)
    fprintf(stream, "\n%s "
            DEBUG_HELP_2
            "[-f[f]|--force [--force]] "
-           "[-h|--help] "
-           "[-y|--yes]\n\t"
-           "[-v|--verbose] "
+           "[-h|--help]\n\t"
+           "[-s|--size PhysicalVolumeSize[kKmMgGtT]] "
+           "[-y|--yes] "
+           "[-v|--verbose]\n\t"
            "[--version] "
            "PhysicalVolume [PhysicalVolume...]\n\n",
            cmd);
@@ -87,17 +94,21 @@ int main ( int argc, char **argv)
    int c1 = 0;
    int force_needed = 0;
    int opt_f = 0;
+   int opt_s = 0;
    int opt_y = 0;
    int ret = 0;
-   int size = 0;
-   char *options = "fh?yv" DEBUG_SHORT_OPTION;
+   uint size = 0;
+   long long opt_s_size = 0;
+   long long pv_size;
+   char *options = "fh?s:yv" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
       DEBUG_LONG_OPTION
-      { "force",   no_argument, NULL, 'f'},
-      { "help",    no_argument, NULL, 'h'},
-      { "yes",     no_argument, NULL, 'y'},
-      { "verbose", no_argument, NULL, 'v'},
-      { "version", no_argument, NULL, 22 },
+      { "force",   no_argument,       NULL, 'f'},
+      { "help",    no_argument,       NULL, 'h'},
+      { "size",    required_argument, NULL, 's'},
+      { "yes",     no_argument,       NULL, 'y'},
+      { "verbose", no_argument,       NULL, 'v'},
+      { "version", no_argument,       NULL, 22 },
       { NULL, 0, NULL, 0}
    };
    char *pv_name = NULL;
@@ -123,6 +134,11 @@ int main ( int argc, char **argv)
             usage(0);
             break;
 
+         case 's':
+            opt_s_size = lvm_check_number_ll ( optarg, TRUE);
+            opt_s++;
+            break;
+
          case 'v':
             opt_v++;
             break;
@@ -177,29 +193,51 @@ int main ( int argc, char **argv)
       }
 
       if ( opt_v > 0) printf ( "%s -- getting physical volume size\n", cmd);
-      if ( ( size = pv_get_size ( pv_name, &part)) < 0) {
-         if ( size == -LVM_EPV_GET_SIZE_PART) {
+      pv_size = pv_get_size_ll ( pv_name, &part);
+      if ( pv_size < 0LL) {
+         if ( pv_size == -LVM_EPV_GET_SIZE_PART) {
             fprintf ( stderr, "%s -- device \"%s\" has a partition table\n",
                               cmd, pv_name);
-         } else if ( size == -LVM_EPV_GET_SIZE_OPEN) {
+         } else if ( pv_size == -LVM_EPV_GET_SIZE_OPEN) {
             fprintf ( stderr, "%s -- can't open physical volume \"%s\" to "
                               "get its size\n",
                               cmd, pv_name);
-         } else if ( size == -LVM_EPV_GET_SIZE_NO_EXTENDED) {
+         } else if ( pv_size == -LVM_EPV_GET_SIZE_NO_EXTENDED) {
             fprintf ( stderr, "%s -- extended partition \"%s\" doesn't exist\n",
                               cmd, pv_name);
-         } else if ( size == -LVM_EPV_GET_SIZE_LVM_DIR_CACHE) {
+         } else if ( pv_size == -LVM_EPV_GET_SIZE_LVM_DIR_CACHE) {
             fprintf ( stderr, "%s -- device \"%s\" doesn't exist\n",
                               cmd, pv_name);
          } else {
             fprintf ( stderr, "%s -- ERROR \"%s\" getting size of physical "
                               "volume \"%s\"\n",
-                              cmd, lvm_error ( size), pv_name);
+                              cmd, lvm_error ( ( int) pv_size), pv_name);
          }
          fputc ( '\n', stderr);
          usage(LVM_EPVCREATE_PV_GET_SIZE);
       }
 
+      if ( opt_s > 0) {
+         if ( opt_s_size <= 0) {
+	    fprintf ( stderr, "%s -- size parameter is invalid\n\n", cmd);
+            usage(LVM_EINVALID_CMD_LINE);
+         }
+         printf ( "%s -- WARNING: overwriting the device size!\n", cmd);
+         pv_size = opt_s_size * 2;
+      }
+
+      if ( opt_v > 0)
+         printf ( "%s -- checking maximum physical volume size\n", cmd);
+      if ( pv_size > LVM_PV_SIZE_MAX) pv_size--;
+      if ( pv_size > LVM_PV_SIZE_MAX) {
+         fprintf ( stderr, "%s -- size %Ld KB is larger than maximum "
+                           "supported size %Ld KB\n",
+                           cmd, pv_size / 2, LVM_PV_SIZE_MAX / 2);
+         usage ( LVM_ELVCREATE_LV_SIZE);
+      }
+      size = pv_size;
+
+
       if ( (ret = pv_check_partitioned_whole(pv_name)) ) {
 	  if (ret ==  -LVM_EPV_GET_SIZE_LVM_DIR_CACHE) {
 	      fprintf ( stderr, "%s -- device \"%s\" doesn't exist\n",
@@ -297,9 +335,9 @@ int main ( int argc, char **argv)
       }
 
       if (pv == NULL) {
-	  fprintf ( stderr, "%s -- invalid physical volume name \"%s\"\n",
+	  fprintf ( stderr, "%s -- invalid physical volume \"%s\"\n\n",
 		    cmd, pv_name);
-	  return LVM_EPVCREATE_PV_CHECK_NAME;
+          return LVM_EPVCREATE_PV_GET_SIZE;
       }
 
       if ( opt_f == 0 && force_needed > 0) {
