@@ -1,12 +1,13 @@
 /*
  * tools/pvscan.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * May, November 1997
  * May,June 1998
  * February,April,May,October 1999
  * February,March 2000
+ * February 2002
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,6 +48,8 @@
  *    17/03/2000 - added -u option to display UUIDs
  *    23/01/2001 - added call to lvm_init (JT)
  *    06/04/2001 - Tidy usage message and command-line options.
+ *    07/02/2002 - fixes for > 1TB support
+ *               - display volume group name of unknown VGs
  *
  */
 
@@ -95,8 +98,8 @@ int main ( int argc, char **argv)
    int ret = 0;
    int vg_name_len = 0;
    int vg_max_name_len = 0;
-   ulong total_cap = 0;
-   ulong new_cap = 0;
+   unsigned long long total_cap = 0;
+   unsigned long long new_cap = 0;
    char *dummy1 = NULL;
    char *dummy2 = NULL;
    char *dummy3 = NULL;
@@ -251,13 +254,14 @@ int main ( int argc, char **argv)
 
          memset ( pv_tmp_name, 0, sizeof ( pv_tmp_name));
          if ( opt_u > 0) {
-            sprintf ( pv_tmp_name,
-                      "\"%-*s\" with UUID \"%s\"",
-                      pv_max_name_len-2,
-                      pv[p]->pv_name,
-                      lvm_show_uuid ( pv[p]->pv_uuid));
+            snprintf ( pv_tmp_name, sizeof ( pv_tmp_name) - 1,
+                                    "\"%-*s\" with UUID \"%s\"",
+                                    pv_max_name_len-2,
+                                    pv[p]->pv_name,
+                                    lvm_show_uuid ( pv[p]->pv_uuid));
          } else {
-            sprintf ( pv_tmp_name, "\"%s\"", pv[p]->pv_name);
+            snprintf ( pv_tmp_name, sizeof ( pv_tmp_name) - 1,
+                                    "\"%s\"", pv[p]->pv_name);
          }
 
          if ( pv_check_new ( pv[p]) == TRUE) {
@@ -277,10 +281,13 @@ int main ( int argc, char **argv)
             free ( dummy2); dummy2 = NULL;
          } else if ( vg_check_name ( pv[p]->vg_name) == 0 &&
                     lvm_tab_vg_check_exist ( pv[p]->vg_name, NULL) != TRUE) {
-            printf ( "PV %-*s  is associated to an unknown VG "
-                     "(run vgscan)\n", pv_max_name_len, pv_tmp_name);
+            printf ( "PV %-*s  is associated to unknown VG \"%s\" "
+                     "(run vgscan)\n",
+                     pv_max_name_len, pv_tmp_name, pv[p]->vg_name);
          } else {
-            sprintf ( vg_tmp_name, "\"%s\"", pv[p]->vg_name);
+            memset ( vg_tmp_name, 0, sizeof ( vg_tmp_name));
+            snprintf ( vg_tmp_name, sizeof ( vg_tmp_name) - 1,
+                                    "\"%s\"", pv[p]->vg_name);
             printf ( "PV %-*s of VG %-*s [%s / %s free]\n",
                      pv_max_name_len, pv_tmp_name, vg_max_name_len,
                      vg_tmp_name,
@@ -305,12 +312,9 @@ int main ( int argc, char **argv)
                ( dummy2 = lvm_show_size ( ( total_cap - new_cap) / 2, SHORT)),
                new_pv,
                ( dummy3 = lvm_show_size ( new_cap / 2, SHORT)));
-      free ( dummy1); dummy1 = NULL;
-      free ( dummy2); dummy2 = NULL;
-      free ( dummy3); dummy3 = NULL;
+      free ( dummy1); free ( dummy2); free ( dummy3);
    }
 
-
    if ( p == 0) return LVM_EPVSCAN_NO_PV_FOUND;
    else         return 0;
 }
