@@ -427,12 +427,11 @@ int main ( int argc, char **argv) {
    if ( ( ret = vg_setup_for_create ( vg_name, &vg, pvp, pe_size,
                                       max_pv, max_lv)) < 0) {
       if ( ret == -LVM_EVG_SETUP_FOR_CREATE_PV_SIZE_MIN) {
-         fprintf ( stderr, "%s -- ERROR: %d physical volume%s too small "
+         fprintf ( stderr, "%s -- ERROR: physical volume(s) too small "
                            "for physical extent size of %s\n"
                            "%s -- minimum physical volume "
                            "at this physical extent size is %s\n\n",
-                           cmd, count_sav, count_sav > 1 ? "s" : "",
-                           vg_name, cmd,
+                           cmd, vg_name, cmd,
                            ( dummy = lvm_show_size ( sectors_to_k(vg.pe_size) *
 			     LVM_PE_SIZE_PV_SIZE_REL,
                              SHORT)));
