@@ -1,12 +1,13 @@
 /*
  * tools/vgimport.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2003  Heinz Mauelshagen, Sistina Software
  *
  * May 1997
  * April-June,September 1998
  * February,May,October 1999
  * February 2000
+ * September 2003
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +44,7 @@
  *    06/10/1999 - implemented support for long options
  *    15/02/2000 - use lvm_error()
  *    23/01/2001 - added call to lvm_init (JT)
+ *    02/09/2003 - free blk_dev_free (HM)
  *
  */
 
@@ -410,6 +412,7 @@ int main ( int argc, char **argv) {
       }
       lv->lv_dev = blk_dev_free[blk_dev++];
    }
+   free ( blk_dev_free);
 
    /* correct status to import */
    vg->vg_status &= ~VG_EXPORTED;
